@@ -1,5 +1,5 @@
 package Test::Mock::Wrapper;
-$Test::Mock::Wrapper::VERSION = '0.12';
+$Test::Mock::Wrapper::VERSION = '0.13';
 use strict;
 use warnings;
 use base qw(Exporter);
@@ -28,7 +28,7 @@ Test::Mock::Wrapper
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -217,7 +217,7 @@ baked in.
 
 sub getObject {
     my $self = shift;
-    return $self->{__mocked};
+    return Test::Mock::Wrapped->new($self, $self->{__object});#$self->{__mocked};
 }
 
 sub _call {
@@ -422,7 +422,7 @@ sub resetAll {
 
 
 package Test::Mock::Wrapper::Method;
-$Test::Mock::Wrapper::Method::VERSION = '0.12';
+$Test::Mock::Wrapper::Method::VERSION = '0.13';
 use Test::Deep;
 use strict;
 use warnings;
@@ -458,7 +458,7 @@ sub hasMock {
 }
 
 package Test::Mock::Wrapper::Method::Mock;
-$Test::Mock::Wrapper::Method::Mock::VERSION = '0.12';
+$Test::Mock::Wrapper::Method::Mock::VERSION = '0.13';
 use Test::Deep;
 use strict;
 use warnings;
@@ -479,7 +479,14 @@ sub new {
 
 sub with {
     my($self, @args) = @_;
-    $self->{_condition} = \@args;
+    if (scalar(@args) > 1) {
+	$self->{_condition} = \@args;
+    }
+    else{
+	$self->{_condition} = shift @args;
+    }
+    
+    #$self->{_condition} = \@args;
     return $self;
 }
 
@@ -496,6 +503,7 @@ sub _isDefault {
 sub _matches {
     my $self = shift;
     my(@args) = @_;
+    
     if (exists $self->{_condition}) {
 	return eq_deeply(\@args, $self->{_condition});
     }else{
@@ -516,7 +524,7 @@ sub _fetchReturn {
 
 
 package Test::Mock::Wrapped;
-$Test::Mock::Wrapped::VERSION = '0.12';
+$Test::Mock::Wrapped::VERSION = '0.13';
 use strict;
 use warnings;
 use Carp;
@@ -538,7 +546,7 @@ sub AUTOLOAD {
     $Test::Mock::Wrapped::AUTOLOAD=~m/::(\w+)$/;
     my $method = $1;
     if ($self->{__controller}->isMocked($method, @args)) {
-	return $self->{__controller}->_call($method, @args);
+	return $self->{__controller}->_call($method, $self, @args);
     }
     else {
 	if ($self->{__object}->can($method)) {
