@@ -1,5 +1,5 @@
 package Test::Mock::Wrapper::Verify;
-$Test::Mock::Wrapper::Verify::VERSION = '0.12';
+$Test::Mock::Wrapper::Verify::VERSION = '0.13';
 use strict;
 use warnings;
 use Test::Deep;
@@ -12,7 +12,7 @@ Test::Mock::Wrapped::Verify - Part of the Test::Mock::Wrapper module
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPIS
 
@@ -59,7 +59,7 @@ supplied matcher. See L<Test::Deep> for information about matcher syntax.
 
 sub with {
     my $self = shift;
-    my $matcher = shift;
+    my($matcher) = @_;
     my (@__calls) = grep({eq_deeply($_, $matcher)} @{ $self->{__calls} });
     return bless({__calls=>\@__calls, method=>$self->{method}}, ref($self));
 }
